@@ -25,9 +25,9 @@
 #include "KonsoleSettings.h"
 
 // System
-#include <errno.h>
-#include <stdlib.h>
-#include <stdio.h>
+#include <cerrno>
+#include <cstdlib>
+#include <cstdio>
 #include <sys/types.h>
 
 // KDE
@@ -436,7 +436,7 @@ CompactHistoryLine::CompactHistoryLine(const TextLine &line, CompactHistoryBlock
 {
     _length = line.size();
 
-    if (line.size() > 0) {
+    if (!line.isEmpty()) {
         _formatLength = 1;
         int k = 1;
 
@@ -453,7 +453,7 @@ CompactHistoryLine::CompactHistoryLine(const TextLine &line, CompactHistoryBlock
         ////qDebug() << "number of different formats in string: " << _formatLength;
         _formatArray = static_cast<CharacterFormat *>(_blockListRef.allocate(sizeof(CharacterFormat) * _formatLength));
         Q_ASSERT(_formatArray != nullptr);
-        _text = static_cast<quint16 *>(_blockListRef.allocate(sizeof(quint16) * line.size()));
+        _text = static_cast<uint *>(_blockListRef.allocate(sizeof(uint) * line.size()));
         Q_ASSERT(_text != nullptr);
 
         _length = line.size();
@@ -614,9 +614,7 @@ HistoryType::~HistoryType() = default;
 
 //////////////////////////////
 
-HistoryTypeNone::HistoryTypeNone()
-{
-}
+HistoryTypeNone::HistoryTypeNone() = default;
 
 bool HistoryTypeNone::isEnabled() const
 {
@@ -699,7 +697,7 @@ int CompactHistoryType::maximumLineCount() const
 HistoryScroll *CompactHistoryType::scroll(HistoryScroll *old) const
 {
     if (old != nullptr) {
-        CompactHistoryScroll *oldBuffer = dynamic_cast<CompactHistoryScroll *>(old);
+        auto *oldBuffer = dynamic_cast<CompactHistoryScroll *>(old);
         if (oldBuffer != nullptr) {
             oldBuffer->setMaxNbLines(_maxLines);
             return oldBuffer;
