@@ -168,7 +168,7 @@ bool KeyBindingEditor::eventFilter(QObject *watched, QEvent *event)
 {
     if (watched == _ui->testAreaInputEdit) {
         if (event->type() == QEvent::KeyPress) {
-            QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+            auto *keyEvent = static_cast<QKeyEvent *>(event);
 
             // The state here is currently set to the state that a newly started
             // terminal in Konsole will be in ( which is also the same as the
@@ -197,7 +197,7 @@ bool KeyBindingEditor::eventFilter(QObject *watched, QEvent *event)
             return true;
         }
     }
-    return false;
+    return QDialog::eventFilter(watched, event);
 }
 
 void KeyBindingEditor::setDescription(const QString &description)
@@ -330,8 +330,9 @@ QSize KeyBindingEditor::sizeHint() const
 {
     const auto parent = parentWidget();
     if (parent != nullptr) {
-        return QSize(parent->width() * 0.9, parent->height() * 0.95);
+        return {static_cast<int>(parent->width() * 0.9),
+                static_cast<int>(parent->height() * 0.95)};
     }
 
-    return QSize();
+    return {};
 }
