@@ -22,6 +22,7 @@
 
 // Qt
 #include <QVBoxLayout>
+#include <QMouseEvent>
 
 // KDE
 #include <KAcceleratorManager>
@@ -54,6 +55,7 @@
 #include "ProfileManager.h"
 #include "KonsoleSettings.h"
 #include "WindowSystemInfo.h"
+#include "TerminalDisplay.h"
 #include "settings/FileLocationSettings.h"
 #include "settings/GeneralSettings.h"
 #include "settings/ProfileSettings.h"
@@ -117,8 +119,7 @@ MainWindow::MainWindow() :
     connect(_viewManager, &Konsole::ViewManager::viewDetached, this,
             &Konsole::MainWindow::viewDetached);
 
-    // create the main widget
-    setupMainWidget();
+    setCentralWidget(_viewManager->widget());
 
     // disable automatically generated accelerators in top-level
     // menu items - to avoid conflicting with Alt+[Letter] shortcuts
@@ -220,6 +221,10 @@ void MainWindow::disconnectController(SessionController *controller)
     disconnect(controller, &Konsole::SessionController::iconChanged,
                this, &Konsole::MainWindow::updateWindowIcon);
 
+    if (auto view = controller->view()) {
+        view->removeEventFilter(this);
+    }
+
     // KXmlGuiFactory::removeClient() will try to access actions associated
     // with the controller internally, which may not be valid after the controller
     // itself is no longer valid (after the associated session and or view have
@@ -243,6 +248,7 @@ void MainWindow::activeViewChanged(SessionController *controller)
 
     Q_ASSERT(controller);
     _pluggedController = controller;
+    _pluggedController->view()->installEventFilter(this);
 
     setBlur(ViewManager::profileHasBlurEnabled(SessionManager::instance()->sessionProfile(_pluggedController->session())));
 
@@ -689,7 +695,7 @@ void MainWindow::showShortcutsDialog()
     if (dialog.configure()) {
         // sync shortcuts for non-session actions (defined in "konsoleui.rc") in other main windows
         foreach (QWidget *mainWindowWidget, QApplication::topLevelWidgets()) {
-            MainWindow *mainWindow = qobject_cast<MainWindow *>(mainWindowWidget);
+            auto *mainWindow = qobject_cast<MainWindow *>(mainWindowWidget);
             if ((mainWindow != nullptr) && mainWindow != this) {
                 syncActiveShortcuts(mainWindow->actionCollection(), actionCollection());
             }
@@ -764,47 +770,11 @@ void MainWindow::applyKonsoleSettings()
         removeMenuAccelerators();
     }
 
-    _viewManager->setNavigationVisibility(KonsoleSettings::tabBarVisibility());
-    _viewManager->setNavigationPosition(KonsoleSettings::tabBarPosition());
     _viewManager->setNavigationBehavior(KonsoleSettings::newTabBehavior());
-    _viewManager->setNavigationTabWidthExpanding(KonsoleSettings::expandTabWidth());
-    _viewManager->setShowQuickButtons(KonsoleSettings::showQuickButtons());
-
-    if (KonsoleSettings::tabBarUseUserStyleSheet()) {
-        setNavigationStyleSheetFromFile(KonsoleSettings::tabBarUserStyleSheetFile());
-    } else {
-        // Apply default values
-        _viewManager->setNavigationStyleSheet(KonsoleSettings::tabBarStyleSheet());
-    }
-
     setAutoSaveSettings(QStringLiteral("MainWindow"), KonsoleSettings::saveGeometryOnExit());
-
     updateWindowCaption();
 }
 
-
-void MainWindow::setNavigationStyleSheetFromFile(const QUrl &styleSheetFile)
-{
-    // Let's only deal w/ local files for now
-    if (!styleSheetFile.isLocalFile()) {
-        _viewManager->setNavigationStyleSheet(KonsoleSettings::tabBarStyleSheet());
-    }
-
-    QFile file(styleSheetFile.toLocalFile());
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        _viewManager->setNavigationStyleSheet(KonsoleSettings::tabBarStyleSheet());
-    }
-
-    QString styleSheetText;
-    QTextStream in(&file);
-    while (!in.atEnd()) {
-        styleSheetText.append(in.readLine());
-    }
-
-    // Replace current style sheet w/ loaded file
-    _viewManager->setNavigationStyleSheet(styleSheetText);
-}
-
 void MainWindow::activateMenuBar()
 {
     const QList<QAction *> menuActions = menuBar()->actions();
@@ -826,20 +796,6 @@ void MainWindow::activateMenuBar()
     menuBar()->setActiveAction(menuAction);
 }
 
-void MainWindow::setupMainWidget()
-{
-    auto mainWindowWidget = new QWidget(this);
-    auto mainWindowLayout = new QVBoxLayout();
-
-    mainWindowLayout->addWidget(_viewManager->widget());
-    mainWindowLayout->setContentsMargins(0, 0, 0, 0);
-    mainWindowLayout->setSpacing(0);
-
-    mainWindowWidget->setLayout(mainWindowLayout);
-
-    setCentralWidget(mainWindowWidget);
-}
-
 void MainWindow::configureNotifications()
 {
     KNotifyConfigWidget::configure(this);
@@ -881,6 +837,37 @@ void MainWindow::showEvent(QShowEvent *event)
     KXmlGuiWindow::showEvent(event);
 }
 
+void MainWindow::triggerAction(const QString &name) const
+{
+    if (auto action = actionCollection()->action(name)) {
+        if (action->isEnabled()) {
+            action->trigger();
+        }
+    }
+}
+
+bool MainWindow::eventFilter(QObject *obj, QEvent *event)
+{
+    if (obj == _pluggedController->view()) {
+        switch(event->type()) {
+        case QEvent::MouseButtonPress:
+        case QEvent::MouseButtonDblClick:
+            switch(static_cast<QMouseEvent*>(event)->button()) {
+            case Qt::ForwardButton:
+                triggerAction(QStringLiteral("next-view"));
+                break;
+            case Qt::BackButton:
+                triggerAction(QStringLiteral("previous-view"));
+                break;
+            default: ;
+            }
+        default: ;
+        }
+    }
+
+    return KXmlGuiWindow::eventFilter(obj, event);
+}
+
 bool MainWindow::focusNextPrevChild(bool)
 {
     // In stand-alone konsole, always disable implicit focus switching
