@@ -25,8 +25,8 @@
 #include "Session.h"
 
 // Standard
-#include <stdlib.h>
-#include <signal.h>
+#include <cstdlib>
+#include <csignal>
 #include <unistd.h>
 
 // Qt
@@ -142,8 +142,6 @@ Session::Session(QObject* parent) :
     _activityTimer = new QTimer(this);
     _activityTimer->setSingleShot(true);
     connect(_activityTimer, &QTimer::timeout, this, &Konsole::Session::activityTimerDone);
-
-    connect(this, &Konsole::Session::tabRenamedByUser, this, &Konsole::Session::tabTitleSetByUser);
 }
 
 Session::~Session()
@@ -336,7 +334,7 @@ void Session::addView(TerminalDisplay* widget)
 
 void Session::viewDestroyed(QObject* view)
 {
-    TerminalDisplay* display = reinterpret_cast<TerminalDisplay*>(view);
+    auto* display = reinterpret_cast<TerminalDisplay*>(view);
 
     Q_ASSERT(_views.contains(display));
 
@@ -897,7 +895,11 @@ void Session::sendTextToTerminal(const QString& text, const QChar& eol) const
         return;
     }
 
-    _emulation->sendText(text + eol);
+    if (eol.isNull()) {
+        _emulation->sendText(text);
+    } else {
+        _emulation->sendText(text + eol);
+    }
 }
 
 // Only D-Bus calls this function (via SendText or runCommand)
@@ -1128,7 +1130,7 @@ QString Session::getDynamicTitle()
     QString title = tabTitleFormat(Session::LocalTabTitle);
     // search for and replace known marker
     title.replace(QLatin1String("%u"), process->userName());
-    title.replace(QLatin1String("%h"), process->localHost());
+    title.replace(QLatin1String("%h"), Konsole::ProcessInfo::localHost());
     title.replace(QLatin1String("%n"), process->name(&ok));
 
     QString dir = _reportedWorkingUrl.toLocalFile();
@@ -1720,7 +1722,7 @@ void SessionGroup::removeSession(Session* session)
 }
 void SessionGroup::sessionFinished()
 {
-    Session* session = qobject_cast<Session*>(sender());
+    auto* session = qobject_cast<Session*>(sender());
     Q_ASSERT(session);
     removeSession(session);
 }
