@@ -67,7 +67,7 @@ class EditProfileDialog;
 // SaveHistoryTask
 class TerminalCharacterDecoder;
 
-typedef QPointer<Session> SessionPtr;
+using SessionPtr = QPointer<Session>;
 
 /**
  * Provides the menu actions to manipulate a single terminal session and view pair.
@@ -219,6 +219,12 @@ public Q_SLOTS:
     /**  Decrease font size */
     void decreaseFontSize();
 
+    /** Reset font size */
+    void resetFontSize();
+
+    /** Close the incremental search */
+    void searchClosed(); // called when the user clicks on the
+
 private Q_SLOTS:
     // menu item handlers
     void openBrowser();
@@ -266,8 +272,6 @@ private Q_SLOTS:
     void sessionReadOnlyChanged();
     void searchTextChanged(const QString &text);
     void searchCompleted(bool success);
-    void searchClosed(); // called when the user clicks on the
-    // history search bar's close button
 
     void updateFilterList(Profile::Ptr profile); // Called when the profile has changed, so we might need to change the list of filters
 
@@ -516,17 +520,15 @@ public:
     void execute() Q_DECL_OVERRIDE;
 
 private:
-    typedef QPointer<ScreenWindow> ScreenWindowPtr;
+    using ScreenWindowPtr = QPointer<ScreenWindow>;
 
     void executeOnScreenWindow(SessionPtr session, ScreenWindowPtr window);
-    void highlightResult(ScreenWindowPtr window, int position);
+    void highlightResult(ScreenWindowPtr window, int findPos);
 
     QMap< SessionPtr, ScreenWindowPtr > _windows;
     QRegularExpression _regExp;
     Enum::SearchDirection _direction;
     int _startLine;
-
-    //static QPointer<SearchHistoryThread> _thread;
 };
 }
 
