@@ -199,7 +199,7 @@ void SessionManager::applyProfile(Session *session, const Profile::Ptr profile,
         // e.g. the second version should be higher than the first one:
         // 18.04.12 -> 180412
         // 18.08.0  -> 180800
-        QStringList list = QStringLiteral(KONSOLE_VERSION).split(QLatin1String("."));
+        QStringList list = QStringLiteral(KONSOLE_VERSION).split(QLatin1Char('.'));
         if (list[2].length() < 2) {
                 list[2].prepend(QLatin1String("0"));
         }
@@ -215,8 +215,8 @@ void SessionManager::applyProfile(Session *session, const Profile::Ptr profile,
 
     if (apply.shouldApply(Profile::TerminalColumns)
         || apply.shouldApply(Profile::TerminalRows)) {
-        const int columns = profile->property<int>(Profile::TerminalColumns);
-        const int rows = profile->property<int>(Profile::TerminalRows);
+        const auto columns = profile->property<int>(Profile::TerminalColumns);
+        const auto rows = profile->property<int>(Profile::TerminalRows);
         session->setPreferredSize(QSize(columns, rows));
     }
 
@@ -243,7 +243,7 @@ void SessionManager::applyProfile(Session *session, const Profile::Ptr profile,
 
     // History
     if (apply.shouldApply(Profile::HistoryMode) || apply.shouldApply(Profile::HistorySize)) {
-        const int mode = profile->property<int>(Profile::HistoryMode);
+        const auto mode = profile->property<int>(Profile::HistoryMode);
         switch (mode) {
         case Enum::NoHistory:
             session->setHistoryType(HistoryTypeNone());
@@ -281,7 +281,7 @@ void SessionManager::applyProfile(Session *session, const Profile::Ptr profile,
 
 void SessionManager::sessionProfileCommandReceived(const QString &text)
 {
-    Session *session = qobject_cast<Session *>(sender());
+    auto *session = qobject_cast<Session *>(sender());
     Q_ASSERT(session);
 
     // store the font for each view if zoom was applied so that they can
